@@ -6,17 +6,21 @@ Test::WWW::Mechanize - Testing-specific WWW::Mechanize subclass
 
 =head1 VERSION
 
-Version 1.10
+Version 1.14
 
 =cut
 
-our $VERSION = '1.10';
+our $VERSION = '1.14';
 
 =head1 SYNOPSIS
 
 Test::WWW::Mechanize is a subclass of L<WWW::Mechanize> that incorporates
 features for web application testing.  For example:
 
+    use Test::More tests => 5;
+    use Test::WWW::Mechanize;
+
+    my $mech = Test::WWW::Mechanize->new;
     $mech->get_ok( $page );
     $mech->base_is( 'http://petdance.com/', 'Proper <BASE HREF>' );
     $mech->title_is( "Invoice Status", "Make sure we're on the invoice page" );
@@ -25,6 +29,10 @@ features for web application testing.  For example:
 
 This is equivalent to:
 
+    use Test::More tests => 5;
+    use WWW::Mechanize;
+
+    my $mech = WWW::Mechanize->new;
     $mech->get( $page );
     ok( $mech->success );
     is( $mech->base, 'http://petdance.com', 'Proper <BASE HREF>' );
@@ -39,9 +47,9 @@ but has nicer diagnostics if they fail.
 use warnings;
 use strict;
 
-use WWW::Mechanize;
-use Test::LongString 0.07;
-use Test::Builder;
+use WWW::Mechanize ();
+use Test::LongString;
+use Test::Builder ();
 use Carp::Assert::More;
 
 use base 'WWW::Mechanize';
@@ -90,13 +98,16 @@ sub get_ok {
 
         if ( !defined( $flex ) ) {
             $desc = shift;
-        } elsif ( ref $flex eq 'HASH' ) {
+        }
+        elsif ( ref $flex eq 'HASH' ) {
             %opts = %$flex;
             $desc = shift;
-        } elsif ( ref $flex eq 'ARRAY' ) {
+        }
+        elsif ( ref $flex eq 'ARRAY' ) {
             %opts = @$flex;
             $desc = shift;
-        } else {
+        }
+        else {
             $desc = $flex;
         }
     } # parms left
@@ -340,6 +351,19 @@ sub _tag_walk {
     return;
 }
 
+=head2 $mech->followable_links()
+
+Returns a list of links that Mech can follow.  This is only http and
+https links.
+
+=cut
+
+sub followable_links {
+    my $self = shift;
+
+    return $self->find_all_links( url_abs_regex => qr[^https?://] );
+}
+
 =head2 $mech->page_links_ok( [ $desc ] )
 
 Follow all links on the current page and test for HTTP status 200
@@ -352,7 +376,7 @@ sub page_links_ok {
     my $self = shift;
     my $desc = shift;
 
-    my @links = $self->links();
+    my @links = $self->followable_links();
     my @urls = _format_links(\@links);
 
     my @failures = $self->_check_links_status( \@urls );
@@ -385,7 +409,7 @@ sub page_links_content_like {
         return $ok;
     }
 
-    my @links = $self->links();
+    my @links = $self->followable_links();
     my @urls = _format_links(\@links);
 
     my @failures = $self->_check_links_content( \@urls, $regex );
@@ -419,7 +443,7 @@ sub page_links_content_unlike {
         return $ok;
     }
 
-    my @links = $self->links();
+    my @links = $self->followable_links();
     my @urls = _format_links(\@links);
 
     my @failures = $self->_check_links_content( \@urls, $regex, 'unlike' );
@@ -433,7 +457,7 @@ sub page_links_content_unlike {
 
 =head2 $mech->links_ok( $links [, $desc ] )
 
-Check the current page for specified links and test for HTTP status
+Follow specified links on the current page and test for HTTP status
 200.  The links may be specified as a reference to an array containing
 L<WWW::Mechanize::Link> objects, an array of URLs, or a scalar URL
 name.
@@ -465,12 +489,12 @@ sub links_ok {
 
 =head2 $mech->link_status_is( $links, $status [, $desc ] )
 
-Check the current page for specified links and test for HTTP status
+Follow specified links on the current page and test for HTTP status
 passed.  The links may be specified as a reference to an array
 containing L<WWW::Mechanize::Link> objects, an array of URLs, or a
 scalar URL name.
 
-    my @links = $mech->links();
+    my @links = $mech->followable_links();
     $mech->link_status_is( \@links, 403,
       'Check all links are restricted' );
 
@@ -494,12 +518,12 @@ sub link_status_is {
 
 =head2 $mech->link_status_isnt( $links, $status [, $desc ] )
 
-Check the current page for specified links and test for HTTP status
+Follow specified links on the current page and test for HTTP status
 passed.  The links may be specified as a reference to an array
 containing L<WWW::Mechanize::Link> objects, an array of URLs, or a
 scalar URL name.
 
-    my @links = $mech->links();
+    my @links = $mech->followable_links();
     $mech->link_status_isnt( \@links, 404,
       'Check all links are not 404' );
 
@@ -524,12 +548,12 @@ sub link_status_isnt {
 
 =head2 $mech->link_content_like( $links, $regex [, $desc ] )
 
-Check the current page for specified links and test the content of
-each against I<$regex>.  The links may be specified as a reference to
-an array containing L<WWW::Mechanize::Link> objects, an array of URLs,
-or a scalar URL name.
+Follow specified links on the current page and test the resulting
+content of each against I<$regex>.  The links may be specified as a
+reference to an array containing L<WWW::Mechanize::Link> objects, an
+array of URLs, or a scalar URL name.
 
-    my @links = $mech->links();
+    my @links = $mech->followable_links();
     $mech->link_content_like( \@links, qr/Restricted/,
         'Check all links are restricted' );
 
@@ -560,12 +584,12 @@ sub link_content_like {
 
 =head2 $mech->link_content_unlike( $links, $regex [, $desc ] )
 
-Check the current page for specified links and test the content of each
-does not match I<$regex>.  The links may be specified as a reference to
-an array containing L<WWW::Mechanize::Link> objects, an array of URLs,
-or a scalar URL name.
+Follow specified links on the current page and test that the resulting
+content of each does not match I<$regex>.  The links may be specified as a
+reference to an array containing L<WWW::Mechanize::Link> objects, an array
+of URLs, or a scalar URL name.
 
-    my @links = $mech->links();
+    my @links = $mech->followable_links();
     $mech->link_content_unlike( \@links, qr/Restricted/,
       'No restricted links' );
 
@@ -611,11 +635,13 @@ sub _check_links_status {
         if ( $mech->follow_link( url => $url ) ) {
             if ( $test eq 'is' ) {
                 push( @failures, $url ) unless $mech->status() == $status;
-            } else {
+            }
+            else {
                 push( @failures, $url ) unless $mech->status() != $status;
             }
             $mech->back();
-        } else {
+        }
+        else {
             push( @failures, $url );
         }
     } # for
@@ -640,11 +666,13 @@ sub _check_links_content {
             my $content=$mech->content();
             if ( $test eq 'like' ) {
                 push( @failures, $url ) unless $content=~/$regex/;
-            } else {
+            }
+            else {
                 push( @failures, $url ) unless $content!~/$regex/;
             }
             $mech->back();
-        } else {
+        }
+        else {
             push( @failures, $url );
         }
     } # for
@@ -661,17 +689,19 @@ sub _format_links {
         if(defined($$links[0])) {
             if(ref($$links[0]) eq 'WWW::Mechanize::Link') {
                 @urls=map { $_->url() } @$links;
-            } else {
+            }
+            else {
                 @urls=@$links;
             }
         }
-    } else {
+    }
+    else {
         push(@urls,$links);
     }
     return @urls;
 }
 
-=head2 follow_link_ok( \%parms [, $comment] )
+=head2 $mech->follow_link_ok( \%parms [, $comment] )
 
 Makes a C<follow_link()> call and executes tests on the results.
 The link must be found, and then followed successfully.  Otherwise,
@@ -681,7 +711,7 @@ I<%parms> is a hashref containing the parms to pass to C<follow_link()>.
 Note that the parms to C<follow_link()> are a hash whereas the parms to
 this function are a hashref.  You have to call this function like:
 
-    $agent->follow_link_ok( {n=>3}, "looking for 3rd link" );
+    $mech->follow_link_ok( {n=>3}, "looking for 3rd link" );
 
 As with other test functions, C<$comment> is optional.  If it is supplied
 then it will display when running the test harness in verbose mode.
@@ -704,10 +734,12 @@ sub follow_link_ok {
     my $error;
     if ( !$response ) {
         $error = "No matching link found";
-    } else {
+    }
+    else {
         if ( !$response->is_success ) {
             $error = $response->as_string;
-        } else {
+        }
+        else {
             $ok = 1;
         }
     }
@@ -718,7 +750,7 @@ sub follow_link_ok {
     return $ok;
 }
 
-=head2 $agent->stuff_inputs( [\%options] )
+=head2 $mech->stuff_inputs( [\%options] )
 
 Finds all free-text input fields (text, textarea, and password) in the
 current form and fills them to their maximum length in hopes of finding
@@ -803,8 +835,7 @@ sub stuff_inputs {
         }
     }
 
-
-    my @inputs = $self->grep_inputs( { type => qr/^(text|textarea|password)$/ } );
+    my @inputs = $self->find_all_inputs( type => qr/^(text|textarea|password)$/ );
 
     foreach my $field ( @inputs ) {
         next if $field->readonly();
@@ -903,6 +934,8 @@ L<http://search.cpan.org/dist/Test-WWW-Mechanize>
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to
+Michael Schwern,
+Mark Blackman,
 Mike O'Regan,
 Shawn Sorichetti,
 Chris Dolan,
@@ -912,7 +945,7 @@ and Pete Krawczyk for patches.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2004-2005 Andy Lester, all rights reserved.
+Copyright 2004-2007 Andy Lester, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
